module Tolq::Parsers::Yaml
  # Unparses a tolq response to YAML suitable for an I18n application
  class Unparser
    # Unparses the tolq response
    #
    # @param tolq_response [Hash] A parsed response from our api
    # @return [String] A yaml formatted string
    def unparse(tolq_response)
      translations = tolq_response['translations']
      split = split_keys(translations.values.first)
      { translations.keys.first => split }.to_yaml
    end

    private

    # Splits a key like 'a.b.c' into { 'a' => 'b' => 'c' }
    #
    # Basically for each key, we split the keys and build the
    # hash bottom up. Then we pass in the result to the next
    # key.
    def split_keys(translations)
      translations.inject({}) do |acc, (k, v)|
        keys = k.split('.')
        deep_merge(acc, keys.reverse.inject(v) { |a, key| { key => a } })
      end
    end

    def deep_merge(original, second)
      merger = Proc.new { |k, x, y| x.is_a?(Hash) ? x.merge(y, &merger) : x || y }
      original.merge(second, &merger)
    end
  end
end
